@@ -5,7 +5,7 @@ no strict 'refs';
 use warnings;
 no warnings 'uninitialized';
 
-our $VERSION = '0.4';
+our $VERSION = '0.5';
 
 use DateTime;
 use Date::Calc qw(Add_Delta_Days Days_in_Month
@@ -17,19 +17,19 @@ sub _ago {
 
     my @new_tokens = splice(@{$self->{tokens}}, $self->{index}, 3);
 
-    if ($new_tokens[1] =~ $self->{data}->ago('hour')) {
+    if ($new_tokens[1] =~ $self->{data}->__ago('hour')) {
         $self->{datetime}->subtract(hours => $new_tokens[0]);
         $self->_set_modified;
-    } elsif ($new_tokens[1] =~ $self->{data}->ago('day')) {
+    } elsif ($new_tokens[1] =~ $self->{data}->__ago('day')) {
         $self->{datetime}->subtract(days => $new_tokens[0]);
         $self->_set_modified;
-    } elsif ($new_tokens[1] =~ $self->{data}->ago('week')) {
+    } elsif ($new_tokens[1] =~ $self->{data}->__ago('week')) {
         $self->{datetime}->subtract(days => (7 * $new_tokens[0]));
         $self->_set_modified;
-    } elsif ($new_tokens[1] =~ $self->{data}->ago('month')) {
+    } elsif ($new_tokens[1] =~ $self->{data}->__ago('month')) {
         $self->{datetime}->subtract(months => $new_tokens[0]);
         $self->_set_modified;
-    } elsif ($new_tokens[1] =~ $self->{data}->ago('year')) {
+    } elsif ($new_tokens[1] =~ $self->{data}->__ago('year')) {
         $self->{datetime}->subtract(years => $new_tokens[0]);
         $self->_set_modified;
     }
@@ -40,35 +40,35 @@ sub _now {
 
     my @new_tokens = splice(@{$self->{tokens}}, $self->{index}, 4);
 
-    if ($new_tokens[1] =~ $self->{data}->now('day')) {
-        if ($new_tokens[2] =~ $self->{data}->now('before')) {
+    if ($new_tokens[1] =~ $self->{data}->__now('day')) {
+        if ($new_tokens[2] =~ $self->{data}->__now('before')) {
             $self->{datetime}->subtract(days => $new_tokens[0]);
             $self->_set_modified;
-        } elsif ($new_tokens[2] =~ $self->{data}->now('from')) {
+        } elsif ($new_tokens[2] =~ $self->{data}->__now('from')) {
             $self->{datetime}->add(days => $new_tokens[0]);
             $self->_set_modified;
         }
-    } elsif ($new_tokens[1] =~ $self->{data}->now('week')) {
-        if ($new_tokens[2] =~ $self->{data}->now('before')) {
+    } elsif ($new_tokens[1] =~ $self->{data}->__now('week')) {
+        if ($new_tokens[2] =~ $self->{data}->__now('before')) {
             $self->{datetime}->subtract(days => (7 * $new_tokens[0]));
             $self->_set_modified;
-        } elsif ($new_tokens[2] =~ $self->{data}->now('from')) {
+        } elsif ($new_tokens[2] =~ $self->{data}->__now('from')) {
             $self->{datetime}->add(days => (7 * $new_tokens[0]));
             $self->_set_modified;
         }
-     } elsif ($new_tokens[1] =~ $self->{data}->now('month')) {
-         if ($new_tokens[2] =~ $self->{data}->now('before')) {
+     } elsif ($new_tokens[1] =~ $self->{data}->__now('month')) {
+         if ($new_tokens[2] =~ $self->{data}->__now('before')) {
              $self->{datetime}->subtract(months => $new_tokens[0]);
              $self->_set_modified;
-         } elsif ($new_tokens[2] =~ $self->{data}->now('from')) {
+         } elsif ($new_tokens[2] =~ $self->{data}->__now('from')) {
              $self->{datetime}->add(months => $new_tokens[0]);
              $self->_set_modified;
          }
-     } elsif ($new_tokens[1] =~ $self->{data}->now('year')) {
-         if ($new_tokens[2] =~ $self->{data}->now('before')) {
+     } elsif ($new_tokens[1] =~ $self->{data}->__now('year')) {
+         if ($new_tokens[2] =~ $self->{data}->__now('before')) {
              $self->{datetime}->subtract(years => $new_tokens[0]);
              $self->_set_modified;
-         } elsif ($new_tokens[2] =~ $self->{data}->now('from')) {
+         } elsif ($new_tokens[2] =~ $self->{data}->__now('from')) {
              $self->{datetime}->add(years => $new_tokens[0]);
              $self->_set_modified;
          }
@@ -79,9 +79,9 @@ sub _daytime {
     my $self = shift;
 
     my $hour_token;
-    my @tokens = @{$self->{data}->daytime('tokens')};
+    my @tokens = @{$self->{data}->__daytime('tokens')};
 
-    unless ($self->{lang} eq 'ge') {
+    unless ($self->{lang} eq 'de') {
         if ($self->{tokens}->[$self->{index}-3]     =~ $tokens[0]
             and $self->{tokens}->[$self->{index}-2] =~ $tokens[1]
             and $self->{tokens}->[$self->{index}-1] =~ $tokens[2]) {
@@ -89,23 +89,13 @@ sub _daytime {
         }
     } elsif ($self->{tokens}->[$self->{index}-2]     =~ $tokens[0] 
              and $self->{tokens}->[$self->{index}-1] =~ $tokens[1]) {
-                    $hour_token = $self->{tokens}->[$self->{index}-2];
+                 $hour_token = $self->{tokens}->[$self->{index}-2];
     }
-    if ($self->{tokens}->[$self->{index}] =~ $self->{data}->daytime('morning')) {
-        # morning & tomorrow shares the same spelling in german
-        if ($self->{lang} eq 'ge') {
-            for my $i qw(0 1 2 3) {
-                if ($self->{tokens}->[$self->{index}+$i] =~ $self->{data}->main('ago')
-                    || $self->{tokens}[$self->{index}-1] =~ $self->{data}->daytime('ago')
-                    || $self->{tokens}[$self->{index}+3] =~ $self->{data}->daytime('ago')) {
-                    return;
-                }
-            }
-        }
+    if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__daytime('morning')) {
         $self->{datetime}->set_hour($hour_token ? $hour_token : '08' - $self->{hours_before});
         undef $self->{hours_before};
         $self->_set_modified;
-    } elsif ($self->{tokens}->[$self->{index}] =~ $self->{data}->daytime('afternoon')) {
+    } elsif ($self->{tokens}->[$self->{index}] =~ $self->{data}->__daytime('afternoon')) {
         $self->{datetime}->set_hour($hour_token ? $hour_token + 12 : '14' - $self->{hours_before});
         undef $self->{hours_before};
         $self->_set_modified;
@@ -128,10 +118,10 @@ sub _months {
                 || $self->{tokens}->[$self->{index}+$i] =~ /$key_month_short/i) {
                    $self->{datetime}->set_month($self->{data}->{months}->{$key_month});
                    $self->_set_modified;
-                   if ($self->{tokens}->[$self->{index}+$i+1] =~ $self->{data}->months('number')) {
+                   if ($self->{tokens}->[$self->{index}+$i+1] =~ $self->{data}->__months('number')) {
                        $self->{datetime}->set_day($1);
                        splice(@{$self->{tokens}}, $self->{index}+$i+1, 1);
-                   } elsif ($self->{tokens}->[$self->{index}+$i-1] =~ $self->{data}->months('number')) {
+                   } elsif ($self->{tokens}->[$self->{index}+$i-1] =~ $self->{data}->__months('number')) {
                       $self->{datetime}->set_day($1);
                       splice(@{$self->{tokens}}, $self->{index}+$i-1, 1);
 
@@ -146,17 +136,17 @@ sub _number {
 
     return if $self->{tokens}->[$self->{index}+1] eq 'in';
 
-    if ($self->{tokens}->[$self->{index}+1] =~ $self->{data}->number('month')) {
+    if ($self->{tokens}->[$self->{index}+1] =~ $self->{data}->__number('month')) {
         $self->{datetime}->add(months => $often);
         if ($self->{datetime}->month() > 12) {
             $self->{datetime}->subtract(months => 12);
         }
         $self->_set_modified;
-    } elsif ($self->{tokens}->[$self->{index}+1] =~ $self->{data}->number('hour')) {
-        if ($self->{tokens}->[$self->{index}+2] =~ $self->{data}->number('before')) {
+    } elsif ($self->{tokens}->[$self->{index}+1] =~ $self->{data}->__number('hour')) {
+        if ($self->{tokens}->[$self->{index}+2] =~ $self->{data}->__number('before')) {
             $self->{hours_before} = $often;
             $self->_set_modified;
-        } elsif ($self->{tokens}->[$self->{index}+2] =~ $self->{data}->number('after')) {
+        } elsif ($self->{tokens}->[$self->{index}+2] =~ $self->{data}->__number('after')) {
             $self->{hours_after} = $often;
             $self->_set_modified;
         }
@@ -192,7 +182,7 @@ sub _at {
     } elsif ($noon_midnight) {
         $self->_set_modified;
         $self->{hours_before} ||= 0;
-        if ($noon_midnight =~ $self->{data}->at('noon')) {
+        if ($noon_midnight =~ $self->{data}->__at('noon')) {
             $self->{datetime}->set_hour(12);
             $self->{datetime}->set_minute(0);
             if ($self->{hours_before}) {
@@ -201,7 +191,7 @@ sub _at {
                 $self->{datetime}->add(hours => $self->{hours_after});
             }
             undef $self->{hours_before};
-        } elsif ($noon_midnight =~ $self->{data}->at('midnight')) {
+        } elsif ($noon_midnight =~ $self->{data}->__at('midnight')) {
             $self->{datetime}->set_hour(0);
             $self->{datetime}->set_minute(0);
             if ($self->{hours_before}) {
@@ -223,11 +213,11 @@ sub _weekday {
             || $self->{tokens}->[$self->{index}] =~ /^$weekday_short$/i) {
             $key_weekday = ucfirst(lc($key_weekday));
             my $days_diff;
-            if ($self->{weekdays}->{$key_weekday} > $self->{datetime}->wday) {
-                $days_diff = $self->{weekdays}->{$key_weekday} - $self->{datetime}->wday;
+            if ($self->{data}->{weekdays}->{$key_weekday} > $self->{datetime}->wday) {
+                $days_diff = $self->{data}->{weekdays}->{$key_weekday} - $self->{datetime}->wday;
                 $self->{datetime}->add(days => $days_diff);
             } else {
-                $days_diff = $self->{datetime}->wday - $self->{weekdays}->{$key_weekday};
+                $days_diff = $self->{datetime}->wday - $self->{data}->{weekdays}->{$key_weekday};
                 $self->{datetime}->subtract(days => $days_diff);
             }
             $self->_set_modified;
@@ -239,24 +229,24 @@ sub _weekday {
 sub _this_in {
     my $self = shift;
 
-    if ($self->{tokens}->[$self->{index}+1] =~ $self->{data}->this_in('hour')) {
+    if ($self->{tokens}->[$self->{index}+1] =~ $self->{data}->__this_in('hour')) {
         $self->{datetime}->add(hours => $self->{tokens}->[$self->{index}]);
         $self->_set_modified;
         return;
     }
 
-    foreach my $key_weekday (keys %{$self->{weekdays}}) {
+    foreach my $key_weekday (keys %{$self->{data}->{weekdays}}) {
         my $weekday_short = lc(substr($key_weekday,0,3));
         if ($self->{tokens}->[$self->{index}] =~ /$key_weekday/i 
             || $self->{tokens}->[$self->{index}] eq $weekday_short) {
-            my $days_diff = $self->{weekdays}->{$key_weekday} - $self->{datetime}->wday;
+            my $days_diff = $self->{data}->{weekdays}->{$key_weekday} - $self->{datetime}->wday;
             $self->{datetime}->add(days => $days_diff);
             $self->{buffer} = '';
             $self->_set_modified;
             last;
         }
 
-        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->this_in('week')) {
+        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__this_in('week')) {
             my $weekday = ucfirst(lc($self->{tokens}->[$self->{index}-2]));
             my $days_diff = Decode_Day_of_Week($weekday) - $self->{datetime}->wday;
             $self->{datetime}->add(days => $days_diff);
@@ -265,15 +255,15 @@ sub _this_in {
             last;
         }
 
-        foreach my $month (keys %{$self->{months}}) {
+        foreach my $month (keys %{$self->{data}->{months}}) {
              if ($self->{tokens}->[$self->{index}] =~ /$month/i) {
-                foreach my $weekday (keys %{$self->{weekdays}}) {
+                foreach my $weekday (keys %{$self->{data}->{weekdays}}) {
                     if ($self->{tokens}->[$self->{index}-2] =~ /$weekday/i) {
 
-                        my ($often) = $self->{tokens}->[$self->{index}-3] =~ $self->{data}->this_in('number');
+                        my ($often) = $self->{tokens}->[$self->{index}-3] =~ $self->{data}->__this_in('number');
                         my ($year, $month, $day) =
-                        Nth_Weekday_of_Month_Year($self->{datetime}->year, $self->{months}->{$month}, 
-                                                  $self->{weekdays}->{$weekday}, $often);
+                        Nth_Weekday_of_Month_Year($self->{datetime}->year, $self->{data}->{months}->{$month}, 
+                                                  $self->{data}->{weekdays}->{$weekday}, $often);
                         $self->{datetime}->set_year($year);
                         $self->{datetime}->set_month($month);
                         $self->{datetime}->set_day($day);
@@ -290,7 +280,7 @@ sub _this_in {
 sub _next {
     my $self = shift;
 
-    foreach my $key_weekday (keys %{$self->{weekdays}}) {
+    foreach my $key_weekday (keys %{$self->{data}->{weekdays}}) {
         my $weekday_short = lc(substr($key_weekday,0,3));
 
         if ($self->{tokens}->[$self->{index}] =~ /$key_weekday/i 
@@ -302,7 +292,7 @@ sub _next {
             last;
         }
 
-        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->next('week')) {
+        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__next('week')) {
             my $weekday = ucfirst(lc($self->{tokens}->[$self->{index}-2]));
             my $days_diff = (7 - $self->{datetime}->wday) + Decode_Day_of_Week($weekday);
             $self->{datetime}->add(days => $days_diff);
@@ -311,11 +301,11 @@ sub _next {
             last;
         }
 
-        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->next('month')) {
+        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__next('month')) {
             $self->{datetime}->add(months => 1);
-            if ($self->{tokens}->[$self->{index}-2] =~ $self->{data}->next('day')) {
+            if ($self->{tokens}->[$self->{index}-2] =~ $self->{data}->__next('day')) {
                 my $day = $self->{tokens}->[$self->{index}-3];
-                $day =~ s/$self->{data}->next('number')/$1/ei;
+                $day =~ s/$self->{data}->__next('number')/$1/ei;
                 $self->{datetime}->set_day($day);
             }
             $self->_setmonthday;
@@ -324,11 +314,11 @@ sub _next {
             last;
         }
 
-        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->next('year')) {
+        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__next('year')) {
             $self->{datetime}->add(years => 1);
-            if ($self->{tokens}->[$self->{index}-2] =~ $self->{data}->next('month')) {
+            if ($self->{tokens}->[$self->{index}-2] =~ $self->{data}->__next('month')) {
                 my $month = $self->{tokens}->[$self->{index}-3];
-                $month =~ s/$self->{data}->next('number')/$1/ei;
+                $month =~ s/$self->{data}->__next('number')/$1/ei;
                 $self->{datetime}->set_month($month);
             }
             $self->_setyearday;
@@ -342,12 +332,12 @@ sub _next {
 sub _last {
     my $self = shift;
 
-    foreach my $key_weekday (keys %{$self->{weekdays}}) {
+    foreach my $key_weekday (keys %{$self->{data}->{weekdays}}) {
         my $weekday_short = lc(substr($key_weekday,0,3));
 
         if ($self->{tokens}->[$self->{index}] =~ /$key_weekday/i 
             || $self->{tokens}->[$self->{index}] eq $weekday_short) {
-            my $days_diff = $self->{datetime}->wday + (7 - $self->{weekdays}->{$key_weekday});
+            my $days_diff = $self->{datetime}->wday + (7 - $self->{data}->{weekdays}->{$key_weekday});
             $self->{datetime}->subtract(days => $days_diff);
             $self->{buffer} = '';
             $self->_set_modified;
@@ -355,35 +345,35 @@ sub _last {
         }
     }
 
-    if ($self->{tokens}->[$self->{index}] =~ $self->{data}->last('week')) {
-        if (exists $self->{weekdays}->{ucfirst(lc($self->{tokens}->[$self->{index}+1]))}) {
+    if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__last('week')) {
+        if (exists $self->{data}->{weekdays}->{ucfirst(lc($self->{tokens}->[$self->{index}+1]))}) {
             $self->_setweekday($self->{index}+1);
-        } elsif (exists $self->{weekdays}->{ucfirst(lc($self->{tokens}->[$self->{index}-2]))}) {
+        } elsif (exists $self->{data}->{weekdays}->{ucfirst(lc($self->{tokens}->[$self->{index}-2]))}) {
             $self->_setweekday($self->{index}-2);
-        } elsif ($self->{tokens}->[$self->{index}-2] =~ $self->{data}->last('day')) {
+        } elsif ($self->{tokens}->[$self->{index}-2] =~ $self->{data}->__last('day')) {
             my $days_diff = (7 + $self->{datetime}->wday);
             $self->{datetime}->subtract(days => $days_diff);
             my $day = $self->{tokens}->[$self->{index}-3];
-            $day =~ s/$self->{data}->last('number')/$1/ei;
+            $day =~ s/$self->{data}->__last('number')/$1/ei;
             $self->{datetime}->add(days => $day);
             $self->{buffer} = '';
             $self->_set_modified;
         }
     }
 
-    if ($self->{tokens}->[$self->{index}] =~ $self->{data}->last('month')) {
+    if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__last('month')) {
         $self->{datetime}->subtract(months => 1);
         $self->_set_modified;
-        if ($self->{tokens}->[$self->{index}-2] =~ $self->{data}->last('day')) {
+        if ($self->{tokens}->[$self->{index}-2] =~ $self->{data}->__last('day')) {
             my $day = $self->{tokens}->[$self->{index}-3];
-            $day =~ s/$self->{data}->last('number')/$1/ei;
+            $day =~ s/$self->{data}->__last('number')/$1/ei;
             $self->{datetime}->set_day($day);
         }
         $self->{buffer} = '';
         $self->_setmonthday;
     }
 
-    if ($self->{tokens}->[$self->{index}] =~ $self->{data}->last('year')) {
+    if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__last('year')) {
         $self->{datetime}->subtract(years => 1);
         $self->_setyearday;
         $self->_set_modified;
@@ -411,20 +401,19 @@ sub _monthdays_limit {
 sub _day {
     my $self = shift;
 
-    if ($self->{tokens}->[$self->{index}] =~ $self->{data}->day('init')) {
-        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->day('yesterday')) {
+    if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__day('init')) {
+        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__day('yesterday')) {
             $self->{datetime}->subtract(days => 1);
         }
         my ($skip1, $skip2) = (0,0);
-        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->day('tomorrow')) {
-            if ($self->{lang} eq 'ge') {
-                if ($self->{tokens}->[$self->{index}] =~ $self->{data}->day('morning_prefix')
-                        || $self->{tokens}[$self->{index}-1] =~ $self->{data}->day('at')
-                        || $self->{tokens}[$self->{index}-1] =~ $self->{data}->day('when')
-                        || scalar @{$self->{tokens}} == 1) {
+        if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__day('tomorrow')) {
+            if ($self->{lang} eq 'de') {
+                if ($self->{tokens}->[$self->{index}] =~ $self->{data}->__day('morning_prefix')
+                        || $self->{tokens}[$self->{index}-1] =~ $self->{data}->__day('at')
+                        || $self->{tokens}[$self->{index}-1] =~ $self->{data}->__day('when')) {
                             $skip1 = 1;
                 }
-                for my $weekday (keys %{$self->{weekdays}}) {
+                for my $weekday (keys %{$self->{data}->{weekdays}}) {
                     if ($self->{tokens}->[$self->{index}-1] =~ /$weekday/i) {
                         $skip2 = 1;
                     }
@@ -439,7 +428,7 @@ sub _day {
 
         if ($self->{hours_before}) {
             $self->{datetime}->set_hour(24 - $self->{hours_before});
-            if ($self->{tokens}->[$self->{index}+2] !~ $self->{data}->day('noonmidnight')) {
+            if ($self->{tokens}->[$self->{index}+2] !~ $self->{data}->__day('noonmidnight')) {
                 $self->{datetime}->subtract(days => 1);
             }
         } elsif ($self->{hours_after}) {
@@ -456,10 +445,10 @@ sub _day {
 sub _setyearday {
     my $self = shift;
 
-    if ($self->{tokens}->[$self->{index}-2] =~ $self->{data}->setyearday('day')) {
+    if ($self->{tokens}->[$self->{index}-2] =~ $self->{data}->__setyearday('day')) {
         $self->{datetime}->set_month(1);
         my $days = $self->{tokens}->[$self->{index}-3];
-        $days =~ s/$self->{data}->setyearday('ext')/$1/ei;
+        $days =~ s/$self->{data}->__setyearday('ext')/$1/ei;
         my ($year, $month, $day) = Add_Delta_Days($self->{datetime}->year, 1, 1, $days - 1);
         $self->{datetime}->set_day($day);
         $self->{datetime}->set_month($month);
@@ -475,7 +464,7 @@ sub _setmonthday {
             my ($often) = $self->{tokens}->[$self->{index}-3] =~ /^(\d{1,2})(?:st|nd|rd|th)?$/i;
             my ($year, $month, $day) =
                 Nth_Weekday_of_Month_Year($self->{datetime}->year, ($self->{datetime}->month),
-                                          $self->{weekdays}->{$weekday}, $often);
+                                          $self->{data}->{weekdays}->{$weekday}, $often);
             $self->{datetime}->set_year($year);
             $self->{datetime}->set_month($month);
             $self->{datetime}->set_day($day);
@@ -487,7 +476,7 @@ sub _setweekday {
     my ($self, $index) = @_;
 
     my $weekday = ucfirst(lc($self->{tokens}->[$index]));
-    my $days_diff = $self->{datetime}->wday + (7 - $self->{weekdays}->{$weekday});
+    my $days_diff = $self->{datetime}->wday + (7 - $self->{data}->{weekdays}->{$weekday});
     $self->{datetime}->subtract(days => $days_diff);
     $self->{buffer} = '';
     $self->_set_modified;
